# LSB Test Execution Framework
# Printing test module
#
# Copyright (C) 2007 The Linux Foundation. All rights reserved.
#
# This program has been developed by ISP RAS for LF with some parts
# derived from lsb-autotest written by Jiri Dluhos <jdluhos@suse.cz>
# Copyright (C) 2005-2007 SuSE Linux Products GmbH
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #

package Printing_test;
use strict;

use Common;
use Packages;

use Tests::X11::X11_common;
@Printing_test::ISA = qw(X11_common);

=head ##
Class Printing_test Inherits X11_common;
=cut ##

sub new {
    my $self  = X11_common->new();
    $self->{NAME} = "printing";
    $self->{DISPLAYNAME} = "Printing Tests";
    $self->{DESCRIPTION} = "This package provides the LSB Runtime Printing Tests,"
                        ." for distribution certification.";
    $self->{PACKAGES} .= " lsb-tet3 lsb-test-printing";
    $self->{SOURCES} .= " runtime";
    $self->{BETA_SOURCES} .= " runtime";
    $self->{SNAPSHOT_SOURCES} .= " /snapshots/printing-test";

    bless($self);
    return $self;
}

sub check {
    my $self = shift;
    
    my $failed = 0;
    
    for my $lib ( "libcups.so.2",  "libcupsimage.so.2") {
        if ( ! -f "/usr/lib/$lib" && ! -f "/usr/lib64/$lib" ) {
            complain("Printing test: install the package that provides"
                    ." $lib and then re-run the tests" );
            $failed = 1;
        }
    }
    for my $app ( "foomatic-rip", "gs", "hpijs" ) {
        if ( ! -x "/usr/bin/$app" ) {
            complain("Printing test: install the package that provides"
                    ." $app and then re-run the tests" );
            $failed = 1;
        }
    }
    
    return 0 if $failed;
    
    return Test_common::check($self);
}

sub stop_cupsd {
    # Trying to stop cupsd gracefully
    for my $script ("cupsys", "cups", "cupsd") {
        if ( -f "/etc/init.d/$script" ) {
            inform("Stop cups daemon");
            cmd("/etc/init.d/$script stop");
            
            last;
        }
    }

    # Kill the cupsd if failed to stop it.
    if ( cmd("ps -A | grep -e '\\bcupsd\$'") == 0 ) {
        cmd ("killall cupsd");
    }
}

sub restart_cupsd {
    
    my $script_found = 0;
    
    # Trying to restart cupsd gracefully
    for my $script ("cupsys", "cups", "cupsd") {
        if ( -f "/etc/init.d/$script" ) {
            inform("Restart cups daemon");
            cmd("/etc/init.d/$script restart");
            
            $script_found = 1;
            last;
        }
    }

    if ( ! $script_found ) {
        # Kill the cupsd if can't find an appropriate script
        if ( cmd("ps -A | grep -e '\\bcupsd\$'") == 0 ) {
            cmd ("killall cupsd");
        }
        
        # Can't start the daemon in this case.
    }
}

# Run the test
sub run
{
    my $self = shift;
    
    my $cups_started = 0;
    # Check cupsd is not running
    if ( cmd("ps -A | grep -e '\\bcupsd\$'") == 0 ) {
        $cups_started = 1;
    }
    
    if ( $cups_started ) {
        stop_cupsd();
    }
   
    # Run the tests
    my $result = Test_common::run($self);

    # Restore the cupsd
    if (!$cups_started) { # Wasn't running
        stop_cupsd();
    } else {
        restart_cupsd();
    }

    return $result;
}

sub journal {
    my $self = shift;
    
    store_journal_info(
        "Certification Tests/Runtime Interface Tests/".$self->{DISPLAYNAME},
        "printing_test", "$results_dir/test_journals/printing_test.journal", 
        $self);
}

1; # return value
